==> phoenix-starter-logging-0.1.10.3-20240527.084458-1-sources.jar: com/elitesland/cbpl/logging/infinity/advice/InfinityLogInterceptor.java <==
package com.elitesland.cbpl.logging.infinity.advice;

import com.elitesland.cbpl.logging.infinity.domain.ResponseVO;
import com.elitesland.cbpl.logging.infinity.service.InfinityTrackService;
import com.elitesland.cbpl.tool.core.exceptions.ExceptionUtils;
import lombok.extern.slf4j.Slf4j;
import org.apache.skywalking.apm.toolkit.trace.TraceContext;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.core.MethodParameter;
import org.springframework.core.annotation.Order;
import org.springframework.http.MediaType;
import org.springframework.http.converter.HttpMessageConverter;
import org.springframework.http.server.ServerHttpRequest;
import org.springframework.http.server.ServerHttpResponse;
import org.springframework.lang.NonNull;
import org.springframework.web.bind.annotation.ControllerAdvice;
import org.springframework.web.servlet.mvc.method.annotation.ResponseBodyAdvice;

/**
 * @author eric.hao
 * @since 2023/06/07
 */
@Slf4j
@ControllerAdvice
@Order()
public class InfinityLogInterceptor implements ResponseBodyAdvice<ResponseVO> {

    @Autowired
    private InfinityTrackService trackService;

    @Override
    public boolean supports(@NonNull MethodParameter returnType, @NonNull Class<? extends HttpMessageConverter<?>> converterType) {
        return ResponseVO.class.isAssignableFrom(returnType.getParameterType());
    }

    @Override
    public ResponseVO beforeBodyWrite(ResponseVO body, @NonNull MethodParameter returnType, @NonNull MediaType selectedContentType,
                                      @NonNull Class<? extends HttpMessageConverter<?>> selectedConverterType,
                                      @NonNull ServerHttpRequest request, @NonNull ServerHttpResponse response) {
        if (body != null) {
            body.setTraceId(TraceContext.traceId());
        }
        try {
            // 记录日志
            trackService.record(request, response, body);
        } catch (Exception e) {
            logger.error("[PHOENIX-LOG] INFINITY RESPONSE ERR: {}", ExceptionUtils.formatException(e));
        }
        return body;
    }
}

==> phoenix-starter-logging-0.1.12-20240731.040015-1-sources.jar: com/elitesland/cbpl/logging/infinity/advice/InfinityLogInterceptor.java <==
package com.elitesland.cbpl.logging.infinity.advice;

import com.elitesland.cbpl.logging.infinity.domain.ResponseVO;
import com.elitesland.cbpl.logging.infinity.service.InfinityTrackService;
import com.elitesland.cbpl.tool.core.exceptions.ExceptionUtils;
import com.lzhpo.tracer.util.TracerUtils;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.core.MethodParameter;
import org.springframework.core.annotation.Order;
import org.springframework.http.MediaType;
import org.springframework.http.converter.HttpMessageConverter;
import org.springframework.http.server.ServerHttpRequest;
import org.springframework.http.server.ServerHttpResponse;
import org.springframework.lang.NonNull;
import org.springframework.web.bind.annotation.ControllerAdvice;
import org.springframework.web.servlet.mvc.method.annotation.ResponseBodyAdvice;

/**
 * @author eric.hao
 * @since 2023/06/07
 */
@Slf4j
@ControllerAdvice
@Order()
public class InfinityLogInterceptor implements ResponseBodyAdvice<ResponseVO> {

    @Autowired
    private InfinityTrackService trackService;

    @Override
    public boolean supports(@NonNull MethodParameter returnType, @NonNull Class<? extends HttpMessageConverter<?>> converterType) {
        return ResponseVO.class.isAssignableFrom(returnType.getParameterType());
    }

    @Override
    public ResponseVO beforeBodyWrite(ResponseVO body, @NonNull MethodParameter returnType, @NonNull MediaType selectedContentType,
                                      @NonNull Class<? extends HttpMessageConverter<?>> selectedConverterType,
                                      @NonNull ServerHttpRequest request, @NonNull ServerHttpResponse response) {
        if (body != null) {
            body.setTraceId(TracerUtils.getTraceId());
        }
        try {
            // 记录日志
            trackService.record(request, response, body);
        } catch (Exception e) {
            logger.error("[PHOENIX-LOG] INFINITY RESPONSE ERR: {}", ExceptionUtils.formatException(e));
        }
        return body;
    }
}
